/*
 *  Copyright (c) 2017 - present, Architecode Corporation. All Rights Reserved.
 *
 *  This source code is licensed under the MIT License.
 *  The LICENSE file can be found in the root directory.
 *
 *  @cix-lic
*/


"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const events_1 = require("events");
const core_1 = require("./core");
const core_2 = require("./core");
class ExtensibleLogger extends events_1.EventEmitter {
    constructor(name, type, logger, properties = {}) {
        super();
        Object.defineProperties(this, {
            "Metadata": {
                configurable: false,
                enumerable: true,
                writable: false,
                value: new core_2.LoggerMetadata(properties.metadata, name, type, logger),
            },
            "Properties": {
                configurable: false,
                enumerable: true,
                writable: false,
                value: properties,
            },
        });
        Object.defineProperties(this, {
            "Author": {
                configurable: false,
                enumerable: true,
                get: () => this.Metadata.Author,
            }
        });
        this.setAuthor(name, type);
        this.configure(name, type, logger, properties);
    }
    setAuthor(name, type) {
        this.Metadata.setAuthor(name, type);
    }
    configure(name, type, logger, properties) {
        const self = this;
        const levels = properties.levels || core_1.DefinedLoggerProperties.levels;
        Object.keys(levels).forEach(level => self[level] = (message, data) => self.log(level, message, data));
    }
}
exports.ExtensibleLogger = ExtensibleLogger;
