/*
 *  Copyright (c) 2017 - present, Architecode Corporation. All Rights Reserved.
 *
 *  This source code is licensed under the MIT License.
 *  The LICENSE file can be found in the root directory.
 *
 *  @cix-lic
*/


"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const archappenv_1 = require("archappenv");
const logger_registry_1 = require("../core/logger.registry");
const core_1 = require("../core");
class LoggerService {
    constructor(options = {}) {
        Object.defineProperties(this, {
            "Registry": {
                configurable: false,
                enumerable: false,
                writable: false,
                value: new logger_registry_1.LoggerRegistry(options)
            },
        });
    }
    static fromConfigFile(configFile) {
        const configFP = archappenv_1.AppEnv.Util.resolvePath(configFile);
        const config = require(configFP);
        const service = new LoggerService(config);
        service.configure(config);
        return service;
    }
    configure(config = {}) {
        if (config.defaultLogger) {
            this.setDefaultLogger(config.defaultLogger.logger, config.defaultLogger.properties);
        }
        if (Array.isArray(config.loggerModules)) {
            config.loggerModules.forEach(each => this.setLoggerModule(each.logger, core_1.Loader.loadLoggerModule(each.module)));
        }
        if (Array.isArray(config.loggerSetups)) {
            config.loggerSetups.forEach(each => this.setLoggerSetup(each.name, each.type, each.logger, each.properties));
        }
    }
    getDefaultLogger() {
        return this.Registry.getDefaultLogger();
    }
    setDefaultLogger(logger, properties) {
        this.Registry.setDefaultLogger(logger, properties);
    }
    getLoggerModule(logger) {
        return this.Registry.getLoggerModule(logger);
    }
    setLoggerModule(logger, LoggerModule) {
        this.Registry.setLoggerModule(logger, LoggerModule);
    }
    hasLoggerModule(logger) {
        return this.Registry.hasLoggerModule(logger);
    }
    getLoggerSetup(name, type) {
        return this.Registry.getLoggerSetup(name, type);
    }
    setLoggerSetup(name, type, logger, properties) {
        this.Registry.setLoggerSetup(name, type, logger, properties);
    }
    hasLoggerSetup(name, type) {
        return this.Registry.hasLoggerSetup(name, type);
    }
    resolveDefaultLogger(name, type, properties) {
        return this.Registry.resolveDefaultLogger(name, type, properties);
    }
    resolveLogger(name, type) {
        return this.Registry.resolveLogger(name, type);
    }
}
exports.LoggerService = LoggerService;
